==> shellcheck-0.4.6-7-i686.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.4.6
id: ShellCheck-0.4.6-3hXYfIxGdYRKN8OI6xXJ01
key: ShellCheck-0.4.6-3hXYfIxGdYRKN8OI6xXJ01
license: GPL-3
maintainer: vidar@vidarholen.net
homepage: http://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
author: Vidar Holen
exposed: True
indefinite: False
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.CheckStyle
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
abi: d63e03f84a57619987601fc8050ff5dc
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/ShellCheck-0.4.6
library-dirs: /usr/lib/ghc-8.2.1/site-local/ShellCheck-0.4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/ShellCheck-0.4.6
hs-libraries: HSShellCheck-0.4.6-3hXYfIxGdYRKN8OI6xXJ01
depends:
    base-4.10.0.0 containers-0.5.10.2 directory-1.3.0.2
    json-0.9.1-H9oi4qjas9E3BwyRmbsDPn mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1 process-1.6.1.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             json-0.9.1-H9oi4qjas9E3BwyRmbsDPn=b4f9db6197ccc25f88a78dce1a672e26
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=2c4212a9c69c9d234eb81396b5fd082b
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.4.6-9-i686.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.4.6
id: ShellCheck-0.4.6-1zOD2LrrUEx55OKIJMgFM5
key: ShellCheck-0.4.6-1zOD2LrrUEx55OKIJMgFM5
license: GPL-3
maintainer: vidar@vidarholen.net
homepage: http://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
author: Vidar Holen
exposed: True
indefinite: False
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.CheckStyle
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
abi: 0f6413a895c893cfff118355ea72e3c5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/ShellCheck-0.4.6
library-dirs: /usr/lib/ghc-8.2.1/site-local/ShellCheck-0.4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/ShellCheck-0.4.6
hs-libraries: HSShellCheck-0.4.6-1zOD2LrrUEx55OKIJMgFM5
depends:
    base-4.10.0.0 containers-0.5.10.2 directory-1.3.0.2
    json-0.9.1-H9oi4qjas9E3BwyRmbsDPn mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX process-1.6.1.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             json-0.9.1-H9oi4qjas9E3BwyRmbsDPn=b4f9db6197ccc25f88a78dce1a672e26
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
